"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HttpMethodType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HttpMethodTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HttpMethodType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HTTP_METHOD_TYPE_INVALID: _HttpMethodType.ValueType  # 0
    HTTP_METHOD_TYPE_GET: _HttpMethodType.ValueType  # 1
    HTTP_METHOD_TYPE_POST: _HttpMethodType.ValueType  # 2
    HTTP_METHOD_TYPE_PUT: _HttpMethodType.ValueType  # 3
    HTTP_METHOD_TYPE_DELETE: _HttpMethodType.ValueType  # 4
    HTTP_METHOD_TYPE_PATCH: _HttpMethodType.ValueType  # 5
    HTTP_METHOD_TYPE_HEAD: _HttpMethodType.ValueType  # 6

class HttpMethodType(_HttpMethodType, metaclass=_HttpMethodTypeEnumTypeWrapper): ...

HTTP_METHOD_TYPE_INVALID: HttpMethodType.ValueType  # 0
HTTP_METHOD_TYPE_GET: HttpMethodType.ValueType  # 1
HTTP_METHOD_TYPE_POST: HttpMethodType.ValueType  # 2
HTTP_METHOD_TYPE_PUT: HttpMethodType.ValueType  # 3
HTTP_METHOD_TYPE_DELETE: HttpMethodType.ValueType  # 4
HTTP_METHOD_TYPE_PATCH: HttpMethodType.ValueType  # 5
HTTP_METHOD_TYPE_HEAD: HttpMethodType.ValueType  # 6
global___HttpMethodType = HttpMethodType

class Notification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POST_SLACK_NOTIFICATION_FIELD_NUMBER: builtins.int
    CUSTOM_WEBHOOK_FIELD_NUMBER: builtins.int
    @property
    def post_slack_notification(self) -> global___PostSlackNotification: ...
    @property
    def custom_webhook(self) -> global___CustomWebhook: ...
    def __init__(
        self,
        *,
        post_slack_notification: global___PostSlackNotification | None = ...,
        custom_webhook: global___CustomWebhook | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_webhook", b"custom_webhook", "notification", b"notification", "post_slack_notification", b"post_slack_notification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_webhook", b"custom_webhook", "notification", b"notification", "post_slack_notification", b"post_slack_notification"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["notification", b"notification"]) -> typing_extensions.Literal["post_slack_notification", "custom_webhook"] | None: ...

global___Notification = Notification

class PostSlackNotification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WEBHOOK_FIELD_NUMBER: builtins.int
    webhook: builtins.str
    def __init__(
        self,
        *,
        webhook: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["webhook", b"webhook"]) -> None: ...

global___PostSlackNotification = PostSlackNotification

class CustomWebhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class DataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    URL_FIELD_NUMBER: builtins.int
    HTTP_METHOD_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    url: builtins.str
    http_method: global___HttpMethodType.ValueType
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        http_method: global___HttpMethodType.ValueType = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "headers", b"headers", "http_method", b"http_method", "url", b"url"]) -> None: ...

global___CustomWebhook = CustomWebhook



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/models/models.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.builds import builds_pb2 as qwak_dot_builds_dot_builds__pb2
from _qwak_proto.qwak.projects import jfrog_project_spec_pb2 as qwak_dot_projects_dot_jfrog__project__spec__pb2
from _qwak_proto.qwak.models import models_query_pb2 as qwak_dot_models_dot_models__query__pb2
from _qwak_proto.qwak.audience.v1 import audience_pb2 as qwak_dot_audience_dot_v1_dot_audience__pb2
from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2
from _qwak_proto.qwak.build.v1 import build_pb2 as qwak_dot_build_dot_v1_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qwak/models/models.proto\x12\x16qwak.models.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18qwak/builds/builds.proto\x1a&qwak/projects/jfrog_project_spec.proto\x1a\x1eqwak/models/models_query.proto\x1a\x1fqwak/audience/v1/audience.proto\x1a qwak/deployment/deployment.proto\x1a\x19qwak/build/v1/build.proto\"\x9b\x01\n\x12\x43reateModelRequest\x12\x35\n\nmodel_spec\x18\x01 \x01(\x0b\x32!.qwak.models.management.ModelSpec\x12N\n\x12jfrog_project_spec\x18\x02 \x01(\x0b\x32\x32.qwak.projects.management.ModelRepositoryJFrogSpec\"\'\n\x13\x43reateModelResponse\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\'\n\x11ListModelsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"C\n\x12ListModelsResponse\x12-\n\x06models\x18\x01 \x03(\x0b\x32\x1d.qwak.models.management.Model\"\xf0\x01\n\x1aListModelsPaginatedRequest\x12\x13\n\tpage_size\x18\x01 \x01(\x05H\x00\x12\x10\n\x06\x63ursor\x18\x02 \x01(\tH\x01\x12\x39\n\x0bsort_models\x18\x03 \x01(\x0b\x32\".qwak.models.management.SortModelsH\x02\x12\x30\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x1e.qwak.models.management.FilterH\x03\x42\x0f\n\rpage_size_optB\x0c\n\ncursor_optB\x11\n\x0fsort_models_optB\x0c\n\nfilter_opt\"\x8a\x01\n\x1bListModelsPaginatedResponse\x12-\n\x06models\x18\x01 \x03(\x0b\x32\x1d.qwak.models.management.Model\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32*.qwak.models.management.PaginationMetadata\"I\n\x0fGetModelRequest\x12\x12\n\x08model_id\x18\x01 \x01(\tH\x00\x12\x14\n\nmodel_uuid\x18\x02 \x01(\tH\x00\x42\x0c\n\nidentifier\"@\n\x10GetModelResponse\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x1d.qwak.models.management.Model\"E\n\x1bListModelsByModelIdsRequest\x12\x11\n\tmodel_ids\x18\x01 \x03(\t\x12\x13\n\x0bmodel_uuids\x18\x02 \x03(\t\":\n\x12\x44\x65leteModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteModelResponse\"q\n\x12UpdateModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12I\n\x11model_spec_config\x18\x02 \x01(\x0b\x32..qwak.models.management.ModelSpecConfiguration\"L\n\x13UpdateModelResponse\x12\x35\n\nmodel_spec\x18\x01 \x01(\x0b\x32!.qwak.models.management.ModelSpec\"<\n\x13\x43reateBranchRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\")\n\x14\x43reateBranchResponse\x12\x11\n\tbranch_id\x18\x01 \x01(\t\"(\n\x13\x44\x65leteBranchRequest\x12\x11\n\tbranch_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteBranchResponse\"N\n\x14IsModelExistsRequest\x12\x12\n\x08model_id\x18\x01 \x01(\tH\x00\x12\x14\n\nmodel_uuid\x18\x02 \x01(\tH\x00\x42\x0c\n\nidentifier\"\'\n\x15IsModelExistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\"\xda\x01\n\tModelSpec\x12\x16\n\x0emodel_named_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x14\n\nproject_id\x18\x03 \x01(\tH\x00\x12\x16\n\x0cproject_name\x18\x06 \x01(\tH\x00\x12\x19\n\x11model_description\x18\x04 \x01(\t\x12@\n\x10model_build_type\x18\x05 \x01(\x0b\x32&.qwak.models.management.ModelBuildTypeB\x14\n\x12project_identifier\"\xc7\x02\n\nModelBrief\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x19\n\x11model_description\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12N\n\x17\x64\x65ployment_model_status\x18\n \x01(\x0e\x32-.qwak.models.management.DeploymentModelStatus\"3\n\x16ModelSpecConfiguration\x12\x19\n\x11model_description\x18\x04 \x01(\t\"\xf4\x04\n\x05Model\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x39\n\x0cmodel_status\x18\x07 \x01(\x0e\x32#.qwak.models.management.ModelStatus\x12\x19\n\x11model_description\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x30\n\x08\x62ranches\x18\n \x03(\x0b\x32\x1e.qwak.models.management.Branch\x12N\n\x17\x64\x65ployment_model_status\x18\x0b \x01(\x0e\x32-.qwak.models.management.DeploymentModelStatus\x12\x0c\n\x04uuid\x18\x0c \x01(\t\x12\x42\n\nmodel_type\x18\r \x01(\x0e\x32..qwak.deployment.management.KubeDeploymentType\x12\x14\n\x0cproject_name\x18\x0e \x01(\t\x12@\n\x10model_build_type\x18\x0f \x01(\x0b\x32&.qwak.models.management.ModelBuildType\x12\x19\n\x11jfrog_project_key\x18\x10 \x01(\t\"\x96\x01\n\x0eModelBuildType\x12\x30\n\x06source\x18\x01 \x01(\x0b\x32\x1e.qwak.models.management.SourceH\x00\x12J\n\x14model_registry_image\x18\x02 \x01(\x0b\x32*.qwak.models.management.ModelRegistryImageH\x00\x42\x06\n\x04type\"\x08\n\x06Source\"3\n\x12ModelRegistryImage\x12\x1d\n\x15last_image_identifier\x18\x01 \x01(\t\"\xeb\x01\n\x06\x42ranch\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\x12\x42\n\rbranch_status\x18\x04 \x01(\x0e\x32+.qwak.models.management.Branch.BranchStatus\x12\x10\n\x08model_id\x18\x05 \x01(\t\x12\x1d\n\x11\x64\x65ployed_build_id\x18\x06 \x01(\tB\x02\x18\x01\"D\n\x0c\x42ranchStatus\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\r\n\tSUSPENDED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x01\"B\n\x1bGetDeploymentDetailsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x11\n\tbranch_id\x18\x02 \x01(\t\"e\n\x1cGetDeploymentDetailsResponse\x12\x45\n\x12\x64\x65ployment_details\x18\x01 \x01(\x0b\x32).qwak.models.management.DeploymentDetails\"\x93\x02\n\x11\x44\x65ploymentDetails\x12\x31\n\rlast_deployed\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x16\n\x0enumber_of_pods\x18\x03 \x01(\x05\x12\x14\n\x0c\x63pu_fraction\x18\x04 \x01(\x02\x12\x15\n\rmemory_amount\x18\x05 \x01(\x05\x12\x38\n\x0cmemory_units\x18\x06 \x01(\x0e\x32\".qwak.models.management.MemoryUnit\x12\x19\n\x11number_of_workers\x18\x07 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x08 \x01(\x05\"/\n\x19ListModelsMetadataRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"[\n\x1aListModelsMetadataResponse\x12=\n\x0emodel_metadata\x18\x01 \x03(\x0b\x32%.qwak.models.management.ModelMetadata\"+\n\x17GetModelMetadataRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"Y\n\x18GetModelMetadataResponse\x12=\n\x0emodel_metadata\x18\x01 \x01(\x0b\x32%.qwak.models.management.ModelMetadata\"h\n\x11\x45nvironmentRoutes\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12>\n\x0f\x61udience_routes\x18\x02 \x03(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry\"\xb8\x05\n\rModelMetadata\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x1d.qwak.models.management.Model\x12I\n\x12\x64\x65ployment_details\x18\x02 \x03(\x0b\x32-.qwak.deployment.management.DeploymentDetails\x12r\n\x1e\x61udience_routes_by_environment\x18\x03 \x03(\x0b\x32\x46.qwak.models.management.ModelMetadata.AudienceRoutesByEnvironmentEntryB\x02\x18\x01\x12\x30\n\x05\x62uild\x18\x04 \x03(\x0b\x32\x1d.qwak.builds.management.BuildB\x02\x18\x01\x12}\n&audience_routes_grouped_by_environment\x18\x05 \x03(\x0b\x32M.qwak.models.management.ModelMetadata.AudienceRoutesGroupedByEnvironmentEntry\x12(\n\x06\x62uilds\x18\x06 \x03(\x0b\x32\x18.com.qwak.build.v1.Build\x1ai\n AudienceRoutesByEnvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry:\x02\x38\x01\x1at\n\'AudienceRoutesGroupedByEnvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qwak.models.management.EnvironmentRoutes:\x02\x38\x01\"i\n CheckModelCreationAllowedRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x18\n\x10model_group_name\x18\x02 \x01(\t\x12\x19\n\x11jfrog_project_key\x18\x03 \x01(\t\"\x9b\x02\n!CheckModelCreationAllowedResponse\x12\x14\n\x0cis_creatable\x18\x01 \x01(\x08\x12;\n\x0cmodel_exists\x18\x02 \x01(\x0b\x32#.qwak.models.management.ModelExistsH\x00\x12\x42\n\x10model_not_exists\x18\x03 \x01(\x0b\x32&.qwak.models.management.ModelNotExistsH\x00\x12U\n\x1amodel_exists_with_mismatch\x18\x04 \x01(\x0b\x32/.qwak.models.management.ModelExistsWithMismatchH\x00\x42\x08\n\x06status\"\r\n\x0bModelExists\"\x10\n\x0eModelNotExists\"*\n\x17ModelExistsWithMismatch\x12\x0f\n\x07\x64\x65tails\x18\x01 \x03(\t*O\n\x15\x44\x65ploymentModelStatus\x12\x1d\n\x19\x44\x45PLOYMENT_STATUS_INVALID\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07OFFLINE\x10\x02*C\n\x0bModelStatus\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\r\n\tSUSPENDED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x01*7\n\nMemoryUnit\x12\x17\n\x13MEMORY_UNIT_UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02\x32\xec\x0c\n\x17ModelsManagementService\x12\x66\n\x0b\x43reateModel\x12*.qwak.models.management.CreateModelRequest\x1a+.qwak.models.management.CreateModelResponse\x12\x63\n\nListModels\x12).qwak.models.management.ListModelsRequest\x1a*.qwak.models.management.ListModelsResponse\x12~\n\x13ListModelsPaginated\x12\x32.qwak.models.management.ListModelsPaginatedRequest\x1a\x33.qwak.models.management.ListModelsPaginatedResponse\x12]\n\x08GetModel\x12\'.qwak.models.management.GetModelRequest\x1a(.qwak.models.management.GetModelResponse\x12w\n\x14ListModelsByModelIds\x12\x33.qwak.models.management.ListModelsByModelIdsRequest\x1a*.qwak.models.management.ListModelsResponse\x12\x66\n\x0b\x44\x65leteModel\x12*.qwak.models.management.DeleteModelRequest\x1a+.qwak.models.management.DeleteModelResponse\x12\x66\n\x0bUpdateModel\x12*.qwak.models.management.UpdateModelRequest\x1a+.qwak.models.management.UpdateModelResponse\x12n\n\x0c\x43reateBranch\x12+.qwak.models.management.CreateBranchRequest\x1a,.qwak.models.management.CreateBranchResponse\"\x03\x88\x02\x01\x12n\n\x0c\x44\x65leteBranch\x12+.qwak.models.management.DeleteBranchRequest\x1a,.qwak.models.management.DeleteBranchResponse\"\x03\x88\x02\x01\x12\x86\x01\n\x14GetDeploymentDetails\x12\x33.qwak.models.management.GetDeploymentDetailsRequest\x1a\x34.qwak.models.management.GetDeploymentDetailsResponse\"\x03\x88\x02\x01\x12l\n\rIsModelExists\x12,.qwak.models.management.IsModelExistsRequest\x1a-.qwak.models.management.IsModelExistsResponse\x12{\n\x12ListModelsMetadata\x12\x31.qwak.models.management.ListModelsMetadataRequest\x1a\x32.qwak.models.management.ListModelsMetadataResponse\x12u\n\x10GetModelMetadata\x12/.qwak.models.management.GetModelMetadataRequest\x1a\x30.qwak.models.management.GetModelMetadataResponse\x12\x90\x01\n\x19\x43heckModelCreationAllowed\x12\x38.qwak.models.management.CheckModelCreationAllowedRequest\x1a\x39.qwak.models.management.CheckModelCreationAllowedResponseB%\n!com.qwak.ai.management.models.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.models.models_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.management.models.apiP\001'
  _BRANCH.fields_by_name['deployed_build_id']._options = None
  _BRANCH.fields_by_name['deployed_build_id']._serialized_options = b'\030\001'
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._options = None
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._serialized_options = b'8\001'
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._options = None
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._serialized_options = b'8\001'
  _MODELMETADATA.fields_by_name['audience_routes_by_environment']._options = None
  _MODELMETADATA.fields_by_name['audience_routes_by_environment']._serialized_options = b'\030\001'
  _MODELMETADATA.fields_by_name['build']._options = None
  _MODELMETADATA.fields_by_name['build']._serialized_options = b'\030\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['CreateBranch']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['CreateBranch']._serialized_options = b'\210\002\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['DeleteBranch']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['DeleteBranch']._serialized_options = b'\210\002\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['GetDeploymentDetails']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['GetDeploymentDetails']._serialized_options = b'\210\002\001'
  _globals['_DEPLOYMENTMODELSTATUS']._serialized_start=5441
  _globals['_DEPLOYMENTMODELSTATUS']._serialized_end=5520
  _globals['_MODELSTATUS']._serialized_start=5522
  _globals['_MODELSTATUS']._serialized_end=5589
  _globals['_MEMORYUNIT']._serialized_start=5591
  _globals['_MEMORYUNIT']._serialized_end=5646
  _globals['_CREATEMODELREQUEST']._serialized_start=278
  _globals['_CREATEMODELREQUEST']._serialized_end=433
  _globals['_CREATEMODELRESPONSE']._serialized_start=435
  _globals['_CREATEMODELRESPONSE']._serialized_end=474
  _globals['_LISTMODELSREQUEST']._serialized_start=476
  _globals['_LISTMODELSREQUEST']._serialized_end=515
  _globals['_LISTMODELSRESPONSE']._serialized_start=517
  _globals['_LISTMODELSRESPONSE']._serialized_end=584
  _globals['_LISTMODELSPAGINATEDREQUEST']._serialized_start=587
  _globals['_LISTMODELSPAGINATEDREQUEST']._serialized_end=827
  _globals['_LISTMODELSPAGINATEDRESPONSE']._serialized_start=830
  _globals['_LISTMODELSPAGINATEDRESPONSE']._serialized_end=968
  _globals['_GETMODELREQUEST']._serialized_start=970
  _globals['_GETMODELREQUEST']._serialized_end=1043
  _globals['_GETMODELRESPONSE']._serialized_start=1045
  _globals['_GETMODELRESPONSE']._serialized_end=1109
  _globals['_LISTMODELSBYMODELIDSREQUEST']._serialized_start=1111
  _globals['_LISTMODELSBYMODELIDSREQUEST']._serialized_end=1180
  _globals['_DELETEMODELREQUEST']._serialized_start=1182
  _globals['_DELETEMODELREQUEST']._serialized_end=1240
  _globals['_DELETEMODELRESPONSE']._serialized_start=1242
  _globals['_DELETEMODELRESPONSE']._serialized_end=1263
  _globals['_UPDATEMODELREQUEST']._serialized_start=1265
  _globals['_UPDATEMODELREQUEST']._serialized_end=1378
  _globals['_UPDATEMODELRESPONSE']._serialized_start=1380
  _globals['_UPDATEMODELRESPONSE']._serialized_end=1456
  _globals['_CREATEBRANCHREQUEST']._serialized_start=1458
  _globals['_CREATEBRANCHREQUEST']._serialized_end=1518
  _globals['_CREATEBRANCHRESPONSE']._serialized_start=1520
  _globals['_CREATEBRANCHRESPONSE']._serialized_end=1561
  _globals['_DELETEBRANCHREQUEST']._serialized_start=1563
  _globals['_DELETEBRANCHREQUEST']._serialized_end=1603
  _globals['_DELETEBRANCHRESPONSE']._serialized_start=1605
  _globals['_DELETEBRANCHRESPONSE']._serialized_end=1627
  _globals['_ISMODELEXISTSREQUEST']._serialized_start=1629
  _globals['_ISMODELEXISTSREQUEST']._serialized_end=1707
  _globals['_ISMODELEXISTSRESPONSE']._serialized_start=1709
  _globals['_ISMODELEXISTSRESPONSE']._serialized_end=1748
  _globals['_MODELSPEC']._serialized_start=1751
  _globals['_MODELSPEC']._serialized_end=1969
  _globals['_MODELBRIEF']._serialized_start=1972
  _globals['_MODELBRIEF']._serialized_end=2299
  _globals['_MODELSPECCONFIGURATION']._serialized_start=2301
  _globals['_MODELSPECCONFIGURATION']._serialized_end=2352
  _globals['_MODEL']._serialized_start=2355
  _globals['_MODEL']._serialized_end=2983
  _globals['_MODELBUILDTYPE']._serialized_start=2986
  _globals['_MODELBUILDTYPE']._serialized_end=3136
  _globals['_SOURCE']._serialized_start=3138
  _globals['_SOURCE']._serialized_end=3146
  _globals['_MODELREGISTRYIMAGE']._serialized_start=3148
  _globals['_MODELREGISTRYIMAGE']._serialized_end=3199
  _globals['_BRANCH']._serialized_start=3202
  _globals['_BRANCH']._serialized_end=3437
  _globals['_BRANCH_BRANCHSTATUS']._serialized_start=3369
  _globals['_BRANCH_BRANCHSTATUS']._serialized_end=3437
  _globals['_GETDEPLOYMENTDETAILSREQUEST']._serialized_start=3439
  _globals['_GETDEPLOYMENTDETAILSREQUEST']._serialized_end=3505
  _globals['_GETDEPLOYMENTDETAILSRESPONSE']._serialized_start=3507
  _globals['_GETDEPLOYMENTDETAILSRESPONSE']._serialized_end=3608
  _globals['_DEPLOYMENTDETAILS']._serialized_start=3611
  _globals['_DEPLOYMENTDETAILS']._serialized_end=3886
  _globals['_LISTMODELSMETADATAREQUEST']._serialized_start=3888
  _globals['_LISTMODELSMETADATAREQUEST']._serialized_end=3935
  _globals['_LISTMODELSMETADATARESPONSE']._serialized_start=3937
  _globals['_LISTMODELSMETADATARESPONSE']._serialized_end=4028
  _globals['_GETMODELMETADATAREQUEST']._serialized_start=4030
  _globals['_GETMODELMETADATAREQUEST']._serialized_end=4073
  _globals['_GETMODELMETADATARESPONSE']._serialized_start=4075
  _globals['_GETMODELMETADATARESPONSE']._serialized_end=4164
  _globals['_ENVIRONMENTROUTES']._serialized_start=4166
  _globals['_ENVIRONMENTROUTES']._serialized_end=4270
  _globals['_MODELMETADATA']._serialized_start=4273
  _globals['_MODELMETADATA']._serialized_end=4969
  _globals['_MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY']._serialized_start=4746
  _globals['_MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY']._serialized_end=4851
  _globals['_MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY']._serialized_start=4853
  _globals['_MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY']._serialized_end=4969
  _globals['_CHECKMODELCREATIONALLOWEDREQUEST']._serialized_start=4971
  _globals['_CHECKMODELCREATIONALLOWEDREQUEST']._serialized_end=5076
  _globals['_CHECKMODELCREATIONALLOWEDRESPONSE']._serialized_start=5079
  _globals['_CHECKMODELCREATIONALLOWEDRESPONSE']._serialized_end=5362
  _globals['_MODELEXISTS']._serialized_start=5364
  _globals['_MODELEXISTS']._serialized_end=5377
  _globals['_MODELNOTEXISTS']._serialized_start=5379
  _globals['_MODELNOTEXISTS']._serialized_end=5395
  _globals['_MODELEXISTSWITHMISMATCH']._serialized_start=5397
  _globals['_MODELEXISTSWITHMISMATCH']._serialized_end=5439
  _globals['_MODELSMANAGEMENTSERVICE']._serialized_start=5649
  _globals['_MODELSMANAGEMENTSERVICE']._serialized_end=7293
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/users/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'qwak/administration/v0/users/user.proto\x12\x18qwak.administration.user\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x03\n\x0cQwakUserSpec\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x39\n\tuser_kind\x18\x03 \x01(\x0e\x32&.qwak.administration.user.QwakUserKind\x12\x38\n\x06status\x18\x04 \x01(\x0e\x32(.qwak.administration.user.QwakUserStatus\x12\x43\n\x0cjob_function\x18\x05 \x01(\x0e\x32-.qwak.administration.user.QwakUserJobFunction\x12=\n\tjob_level\x18\x06 \x01(\x0e\x32*.qwak.administration.user.QwakUserJobLevel\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\ttime_zone\x18\t \x01(\t\"Y\n\x08QwakUser\x12\x34\n\x04spec\x18\x01 \x01(\x0b\x32&.qwak.administration.user.QwakUserSpec\x12\x17\n\x0f\x65nvironment_ids\x18\x02 \x03(\t*[\n\x0eQwakUserStatus\x12\x17\n\x13USER_STATUS_INVALID\x10\x00\x12\x16\n\x12USER_STATUS_ACTIVE\x10\x01\x12\x18\n\x14USER_STATUS_DISABLED\x10\x02*\xcb\x01\n\x13QwakUserJobFunction\x12\x18\n\x14JOB_FUNCTION_INVALID\x10\x00\x12\x1e\n\x1aJOB_FUNCTION_DATA_ENGINEER\x10\x01\x12\x1f\n\x1bJOB_FUNCTION_DATA_SCIENTIST\x10\x02\x12\x1c\n\x18JOB_FUNCTION_ML_ENGINEER\x10\x03\x12\x17\n\x13JOB_FUNCTION_DEVOPS\x10\x04\x12\"\n\x1eJOB_FUNCTION_SOFTWARE_ENGINEER\x10\x05*\xc5\x01\n\x10QwakUserJobLevel\x12\x15\n\x11JOB_LEVEL_INVALID\x10\x00\x12$\n JOB_LEVEL_INDIVIDUAL_CONTRIBUTOR\x10\x01\x12\x17\n\x13JOB_LEVEL_ARCHITECT\x10\x02\x12\x15\n\x11JOB_LEVEL_MANAGER\x10\x03\x12\x16\n\x12JOB_LEVEL_DIRECTOR\x10\x04\x12\x15\n\x11JOB_LEVEL_P_OR_VP\x10\x05\x12\x15\n\x11JOB_LEVEL_C_LEVEL\x10\x06*\xd5\x01\n\x0cQwakUserKind\x12\x15\n\x11USER_KIND_INVALID\x10\x00\x12\x1e\n\x1aUSER_KIND_QWAK_SIMPLE_USER\x10\x01\x12\x18\n\x14USER_KIND_QWAK_ADMIN\x10\x02\x12+\n#USER_KIND_QWAK_SERVICE_ACCOUNT_CORE\x10\x03\x1a\x02\x08\x01\x12+\n#USER_KIND_QWAK_SERVICE_ACCOUNT_EDGE\x10\x04\x1a\x02\x08\x01\x12\x1a\n\x16USER_KIND_QWAK_SUPPORT\x10\x05*y\n\x0fQwakAccountRole\x12\x18\n\x14\x41\x43\x43OUNT_ROLE_INVALID\x10\x00\x12\x16\n\x12\x41\x43\x43OUNT_ROLE_ADMIN\x10\x01\x12\x1b\n\x17\x41\x43\x43OUNT_ROLE_MAINTAINER\x10\x03\x12\x17\n\x13\x41\x43\x43OUNT_ROLE_MEMBER\x10\x02\x42\xa5\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x80\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/users;users_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.v0.users.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\200\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/users;users_v0'
  _QWAKUSERKIND.values_by_name["USER_KIND_QWAK_SERVICE_ACCOUNT_CORE"]._options = None
  _QWAKUSERKIND.values_by_name["USER_KIND_QWAK_SERVICE_ACCOUNT_CORE"]._serialized_options = b'\010\001'
  _QWAKUSERKIND.values_by_name["USER_KIND_QWAK_SERVICE_ACCOUNT_EDGE"]._options = None
  _QWAKUSERKIND.values_by_name["USER_KIND_QWAK_SERVICE_ACCOUNT_EDGE"]._serialized_options = b'\010\001'
  _globals['_QWAKUSERSTATUS']._serialized_start=614
  _globals['_QWAKUSERSTATUS']._serialized_end=705
  _globals['_QWAKUSERJOBFUNCTION']._serialized_start=708
  _globals['_QWAKUSERJOBFUNCTION']._serialized_end=911
  _globals['_QWAKUSERJOBLEVEL']._serialized_start=914
  _globals['_QWAKUSERJOBLEVEL']._serialized_end=1111
  _globals['_QWAKUSERKIND']._serialized_start=1114
  _globals['_QWAKUSERKIND']._serialized_end=1327
  _globals['_QWAKACCOUNTROLE']._serialized_start=1329
  _globals['_QWAKACCOUNTROLE']._serialized_end=1450
  _globals['_QWAKUSERSPEC']._serialized_start=103
  _globals['_QWAKUSERSPEC']._serialized_end=521
  _globals['_QWAKUSER']._serialized_start=523
  _globals['_QWAKUSER']._serialized_end=612
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sinks/sink.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.sources import streaming_pb2 as qwak_dot_feature__store_dot_sources_dot_streaming__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/feature_store/sinks/sink.proto\x12\x18qwak.feature.store.sinks\x1a*qwak/feature_store/sources/streaming.proto\"\xb3\x01\n\rStreamingSink\x12L\n\x10\x61ttachment_point\x18\x01 \x01(\x0b\x32\x32.qwak.feature.store.sinks.StreamingAttachmentPoint\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x39\n\nkafka_sink\x18\x02 \x01(\x0b\x32#.qwak.feature.store.sinks.KafkaSinkH\x00\x42\x0b\n\tsink_type\"\xb9\x01\n\tKafkaSink\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x19\n\x11\x62ootstrap_servers\x18\x02 \x01(\t\x12\x41\n\x0emessage_format\x18\x03 \x01(\x0e\x32).qwak.feature.store.sources.MessageFormat\x12?\n\x0b\x61uth_config\x18\x04 \x01(\x0b\x32*.qwak.feature.store.sources.Authentication\" \n\x1eOnlineStreamingAttachmentPoint\"!\n\x1fOfflineStreamingAttachmentPoint\"\x83\x02\n\x18StreamingAttachmentPoint\x12\x65\n!online_streaming_attachment_point\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.sinks.OnlineStreamingAttachmentPointH\x00\x12g\n\"offline_streaming_attachment_point\x18\x02 \x01(\x0b\x32\x39.qwak.feature.store.sinks.OfflineStreamingAttachmentPointH\x00\x42\x17\n\x15\x61ttachment_point_typeBR\n#com.qwak.ai.feature.store.sinks.apiP\x01Z)qwak/featurestore/sinks;featurestoresinksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sinks.sink_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.feature.store.sinks.apiP\001Z)qwak/featurestore/sinks;featurestoresinks'
  _globals['_STREAMINGSINK']._serialized_start=110
  _globals['_STREAMINGSINK']._serialized_end=289
  _globals['_KAFKASINK']._serialized_start=292
  _globals['_KAFKASINK']._serialized_end=477
  _globals['_ONLINESTREAMINGATTACHMENTPOINT']._serialized_start=479
  _globals['_ONLINESTREAMINGATTACHMENTPOINT']._serialized_end=511
  _globals['_OFFLINESTREAMINGATTACHMENTPOINT']._serialized_start=513
  _globals['_OFFLINESTREAMINGATTACHMENTPOINT']._serialized_end=546
  _globals['_STREAMINGATTACHMENTPOINT']._serialized_start=549
  _globals['_STREAMINGATTACHMENTPOINT']._serialized_end=808
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RepositoryDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_TYPE_FIELD_NUMBER: builtins.int
    REPOSITORY_KEY_FIELD_NUMBER: builtins.int
    @property
    def repository_type(self) -> global___RepositoryType:
        """The repository type"""
    repository_key: builtins.str
    """The repository key is the full repository path, e.g. <jfrog_project_key><model>-docker-local"""
    def __init__(
        self,
        *,
        repository_type: global___RepositoryType | None = ...,
        repository_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repository_type", b"repository_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository_key", b"repository_key", "repository_type", b"repository_type"]) -> None: ...

global___RepositoryDetails = RepositoryDetails

class RemoteRepositoryDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCKER_REPOSITORY_FIELD_NUMBER: builtins.int
    HUGGING_FACE_REPOSITORY_FIELD_NUMBER: builtins.int
    NPM_REPOSITORY_FIELD_NUMBER: builtins.int
    PYPI_REPOSITORY_FIELD_NUMBER: builtins.int
    REPOSITORY_REMOTE_URL_FIELD_NUMBER: builtins.int
    @property
    def docker_repository(self) -> global___DockerRepository:
        """Docker repository"""
    @property
    def hugging_face_repository(self) -> global___HuggingFaceRepository:
        """HuggingFace repository"""
    @property
    def npm_repository(self) -> global___NpmRepository:
        """NPM repository"""
    @property
    def pypi_repository(self) -> global___PypiRepository:
        """PyPI repository"""
    repository_remote_url: builtins.str
    """The remote repository URL"""
    def __init__(
        self,
        *,
        docker_repository: global___DockerRepository | None = ...,
        hugging_face_repository: global___HuggingFaceRepository | None = ...,
        npm_repository: global___NpmRepository | None = ...,
        pypi_repository: global___PypiRepository | None = ...,
        repository_remote_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["docker_repository", b"docker_repository", "hugging_face_repository", b"hugging_face_repository", "npm_repository", b"npm_repository", "pypi_repository", b"pypi_repository", "repository_type", b"repository_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["docker_repository", b"docker_repository", "hugging_face_repository", b"hugging_face_repository", "npm_repository", b"npm_repository", "pypi_repository", b"pypi_repository", "repository_remote_url", b"repository_remote_url", "repository_type", b"repository_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["repository_type", b"repository_type"]) -> typing_extensions.Literal["docker_repository", "hugging_face_repository", "npm_repository", "pypi_repository"] | None: ...

global___RemoteRepositoryDetails = RemoteRepositoryDetails

class DockerRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DockerRepository = DockerRepository

class DatasetRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DatasetRepository = DatasetRepository

class ArtifactRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ArtifactRepository = ArtifactRepository

class HuggingFaceRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HuggingFaceRepository = HuggingFaceRepository

class NpmRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NpmRepository = NpmRepository

class PypiRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PypiRepository = PypiRepository

class RepositoryType(google.protobuf.message.Message):
    """The repository type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCKER_REPOSITORY_FIELD_NUMBER: builtins.int
    DATASET_REPOSITORY_FIELD_NUMBER: builtins.int
    ARTIFACT_REPOSITORY_FIELD_NUMBER: builtins.int
    HUGGING_FACE_REPOSITORY_FIELD_NUMBER: builtins.int
    NPM_REPOSITORY_FIELD_NUMBER: builtins.int
    PYPI_REPOSITORY_FIELD_NUMBER: builtins.int
    @property
    def docker_repository(self) -> global___DockerRepository:
        """Docker repository"""
    @property
    def dataset_repository(self) -> global___DatasetRepository:
        """Dataset repository"""
    @property
    def artifact_repository(self) -> global___ArtifactRepository:
        """Artifact repository"""
    @property
    def hugging_face_repository(self) -> global___HuggingFaceRepository:
        """HuggingFace repository"""
    @property
    def npm_repository(self) -> global___NpmRepository:
        """NPM repository"""
    @property
    def pypi_repository(self) -> global___PypiRepository:
        """PyPI repository"""
    def __init__(
        self,
        *,
        docker_repository: global___DockerRepository | None = ...,
        dataset_repository: global___DatasetRepository | None = ...,
        artifact_repository: global___ArtifactRepository | None = ...,
        hugging_face_repository: global___HuggingFaceRepository | None = ...,
        npm_repository: global___NpmRepository | None = ...,
        pypi_repository: global___PypiRepository | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifact_repository", b"artifact_repository", "dataset_repository", b"dataset_repository", "docker_repository", b"docker_repository", "hugging_face_repository", b"hugging_face_repository", "npm_repository", b"npm_repository", "pypi_repository", b"pypi_repository", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_repository", b"artifact_repository", "dataset_repository", b"dataset_repository", "docker_repository", b"docker_repository", "hugging_face_repository", b"hugging_face_repository", "npm_repository", b"npm_repository", "pypi_repository", b"pypi_repository", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["docker_repository", "dataset_repository", "artifact_repository", "hugging_face_repository", "npm_repository", "pypi_repository"] | None: ...

global___RepositoryType = RepositoryType



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.traffic.v1.traffic_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ResetAndSetTrafficStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MULTIPLE_HTTP_TRAFFIC_FIELD_NUMBER: builtins.int
    @property
    def multiple_http_traffic(self) -> qwak.traffic.v1.traffic_pb2.MultipleHttpTraffic: ...
    def __init__(
        self,
        *,
        multiple_http_traffic: qwak.traffic.v1.traffic_pb2.MultipleHttpTraffic | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["multiple_http_traffic", b"multiple_http_traffic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["multiple_http_traffic", b"multiple_http_traffic"]) -> None: ...

global___ResetAndSetTrafficStateRequest = ResetAndSetTrafficStateRequest

class ResetAndSetTrafficStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ResetAndSetTrafficStateResponse = ResetAndSetTrafficStateResponse

class ApplyGroupedTrafficRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MULTIPLE_HTTP_TRAFFIC_FIELD_NUMBER: builtins.int
    GROUP_ID_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    @property
    def multiple_http_traffic(self) -> qwak.traffic.v1.traffic_pb2.MultipleHttpTraffic: ...
    group_id: builtins.str
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        multiple_http_traffic: qwak.traffic.v1.traffic_pb2.MultipleHttpTraffic | None = ...,
        group_id: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["multiple_http_traffic", b"multiple_http_traffic", "traffic", b"traffic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_id", b"group_id", "hosts", b"hosts", "multiple_http_traffic", b"multiple_http_traffic", "traffic", b"traffic"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["traffic", b"traffic"]) -> typing_extensions.Literal["multiple_http_traffic"] | None: ...

global___ApplyGroupedTrafficRequest = ApplyGroupedTrafficRequest

class ApplyGroupedTrafficResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ApplyGroupedTrafficResponse = ApplyGroupedTrafficResponse

class CreateEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    VARIATION_FIELD_NUMBER: builtins.int
    HTTP_REQUEST_TIMEOUT_MS_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    endpoint: builtins.str
    variation: builtins.str
    http_request_timeout_ms: builtins.int
    """Http request timeout in ms"""
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Hosts to be used for this endpoint"""
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        endpoint: builtins.str = ...,
        variation: builtins.str = ...,
        http_request_timeout_ms: builtins.int = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "group_id", b"group_id", "hosts", b"hosts", "http_request_timeout_ms", b"http_request_timeout_ms", "variation", b"variation"]) -> None: ...

global___CreateEndpointRequest = CreateEndpointRequest

class CreateEndpointResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateEndpointResponse = CreateEndpointResponse

class DeleteEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_id", b"group_id"]) -> None: ...

global___DeleteEndpointRequest = DeleteEndpointRequest

class DeleteEndpointResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteEndpointResponse = DeleteEndpointResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RepositoryType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RepositoryTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RepositoryType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REPOSITORY_TYPE_UNSPECIFIED: _RepositoryType.ValueType  # 0
    LOCAL: _RepositoryType.ValueType  # 1
    REMOTE: _RepositoryType.ValueType  # 2

class RepositoryType(_RepositoryType, metaclass=_RepositoryTypeEnumTypeWrapper): ...

REPOSITORY_TYPE_UNSPECIFIED: RepositoryType.ValueType  # 0
LOCAL: RepositoryType.ValueType  # 1
REMOTE: RepositoryType.ValueType  # 2
global___RepositoryType = RepositoryType

class _JFrogPermissionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _JFrogPermissionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_JFrogPermissionType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JFROG_PERMISSION_TYPE_UNSPECIFIED: _JFrogPermissionType.ValueType  # 0
    """Unspecified permission type"""
    READ: _JFrogPermissionType.ValueType  # 1
    """Action: `r` - Read Permssions"""
    WRITE: _JFrogPermissionType.ValueType  # 2
    """Action: `w` - Write/ Deploy/Cache Permssions. Needed to e.g. push images, or cache images in remote repos."""
    DELETE: _JFrogPermissionType.ValueType  # 3
    """Action: `d` - Delete permission"""
    ANNOTATE: _JFrogPermissionType.ValueType  # 4
    """Action: `a`"""
    EXECUTE: _JFrogPermissionType.ValueType  # 5
    """Action: `x`"""
    SCAN: _JFrogPermissionType.ValueType  # 6
    """Action: `s`"""
    MANAGE: _JFrogPermissionType.ValueType  # 7
    """Action: `m` - Manage permission"""

class JFrogPermissionType(_JFrogPermissionType, metaclass=_JFrogPermissionTypeEnumTypeWrapper):
    """JFrog permission types.
    Options are taken from https://jfrog.com/help/r/jfrog-rest-apis/create-scoped-token
    """

JFROG_PERMISSION_TYPE_UNSPECIFIED: JFrogPermissionType.ValueType  # 0
"""Unspecified permission type"""
READ: JFrogPermissionType.ValueType  # 1
"""Action: `r` - Read Permssions"""
WRITE: JFrogPermissionType.ValueType  # 2
"""Action: `w` - Write/ Deploy/Cache Permssions. Needed to e.g. push images, or cache images in remote repos."""
DELETE: JFrogPermissionType.ValueType  # 3
"""Action: `d` - Delete permission"""
ANNOTATE: JFrogPermissionType.ValueType  # 4
"""Action: `a`"""
EXECUTE: JFrogPermissionType.ValueType  # 5
"""Action: `x`"""
SCAN: JFrogPermissionType.ValueType  # 6
"""Action: `s`"""
MANAGE: JFrogPermissionType.ValueType  # 7
"""Action: `m` - Manage permission"""
global___JFrogPermissionType = JFrogPermissionType

class JFrogToken(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////////////////////////////////////////////
    definition
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFINITION_FIELD_NUMBER: builtins.int
    TENANT_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def definition(self) -> global___JFrogTokenDefinition:
        """Token definition"""
    @property
    def tenant_details(self) -> global___JFrogTokenTenantDetails:
        """JFrog Tenant details"""
    def __init__(
        self,
        *,
        definition: global___JFrogTokenDefinition | None = ...,
        tenant_details: global___JFrogTokenTenantDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition", "tenant_details", b"tenant_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "tenant_details", b"tenant_details"]) -> None: ...

global___JFrogToken = JFrogToken

class JFrogTokenTenantDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_URL_FIELD_NUMBER: builtins.int
    platform_url: builtins.str
    """Tenant platform url"""
    def __init__(
        self,
        *,
        platform_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["platform_url", b"platform_url"]) -> None: ...

global___JFrogTokenTenantDetails = JFrogTokenTenantDetails

class JFrogTokenDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    SUBJECT_NAME_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    token: builtins.str
    """The generated token"""
    refresh_token: builtins.str
    @property
    def expiration_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    subject: builtins.str
    """Token subject"""
    subject_name: builtins.str
    """Token subject name
    For users: username, otherwise subject
    (use this as the username for docker login)
    """
    token_id: builtins.str
    """Token Id"""
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        refresh_token: builtins.str = ...,
        expiration_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        subject: builtins.str = ...,
        subject_name: builtins.str = ...,
        token_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "optional_expiration_time", b"optional_expiration_time", "optional_refresh_token", b"optional_refresh_token", "refresh_token", b"refresh_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "optional_expiration_time", b"optional_expiration_time", "optional_refresh_token", b"optional_refresh_token", "refresh_token", b"refresh_token", "subject", b"subject", "subject_name", b"subject_name", "token", b"token", "token_id", b"token_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_expiration_time", b"optional_expiration_time"]) -> typing_extensions.Literal["expiration_time"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_refresh_token", b"optional_refresh_token"]) -> typing_extensions.Literal["refresh_token"] | None: ...

global___JFrogTokenDefinition = JFrogTokenDefinition

class JFrogTokenSpec(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////////////////////////////////////////////
    spec
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_TENANT_ID_FIELD_NUMBER: builtins.int
    SUBJECT_AND_SCOPE_SOURCE_FIELD_NUMBER: builtins.int
    AUDIENCES_FIELD_NUMBER: builtins.int
    TTL_SPEC_FIELD_NUMBER: builtins.int
    jfrog_tenant_id: builtins.str
    """JFrog tenant id"""
    @property
    def subject_and_scope_source(self) -> global___SubjectAndScopeSource:
        """Subject and scope source"""
    @property
    def audiences(self) -> global___JFrogTokenAudiences:
        """Audiences
        Optional, if empty- *@* will be used
        """
    @property
    def ttl_spec(self) -> global___JFrogTokenTTLSpec:
        """Ttl spec"""
    def __init__(
        self,
        *,
        jfrog_tenant_id: builtins.str = ...,
        subject_and_scope_source: global___SubjectAndScopeSource | None = ...,
        audiences: global___JFrogTokenAudiences | None = ...,
        ttl_spec: global___JFrogTokenTTLSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audiences", b"audiences", "subject_and_scope_source", b"subject_and_scope_source", "ttl_spec", b"ttl_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audiences", b"audiences", "jfrog_tenant_id", b"jfrog_tenant_id", "subject_and_scope_source", b"subject_and_scope_source", "ttl_spec", b"ttl_spec"]) -> None: ...

global___JFrogTokenSpec = JFrogTokenSpec

class ArtifactoryImagePullTokenSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_TENANT_ID_FIELD_NUMBER: builtins.int
    REPOSITORY_KEY_FIELD_NUMBER: builtins.int
    TTL_SPEC_FIELD_NUMBER: builtins.int
    REPOSITORY_KEYS_FIELD_NUMBER: builtins.int
    REPOSITORY_TOKEN_SPECS_FIELD_NUMBER: builtins.int
    jfrog_tenant_id: builtins.str
    """JFrog tenant id"""
    repository_key: builtins.str
    """Artifactory repository key
    Deprecated: use `repository_keys` instead.
    """
    @property
    def ttl_spec(self) -> global___JFrogTokenTTLSpec:
        """Ttl spec"""
    @property
    def repository_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Deprecated: use `repository_token_specs` instead."""
    @property
    def repository_token_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RepositoryTokenSpec]:
        """Repository token specifications"""
    def __init__(
        self,
        *,
        jfrog_tenant_id: builtins.str = ...,
        repository_key: builtins.str = ...,
        ttl_spec: global___JFrogTokenTTLSpec | None = ...,
        repository_keys: collections.abc.Iterable[builtins.str] | None = ...,
        repository_token_specs: collections.abc.Iterable[global___RepositoryTokenSpec] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ttl_spec", b"ttl_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_tenant_id", b"jfrog_tenant_id", "repository_key", b"repository_key", "repository_keys", b"repository_keys", "repository_token_specs", b"repository_token_specs", "ttl_spec", b"ttl_spec"]) -> None: ...

global___ArtifactoryImagePullTokenSpec = ArtifactoryImagePullTokenSpec

class PersistTokenClaimsSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_TENANT_ID_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    TOKEN_SCOPE_EXTENSION_FIELD_NUMBER: builtins.int
    jfrog_tenant_id: builtins.str
    """JFrog tenant id"""
    token: builtins.str
    """Token to persist"""
    @property
    def token_scope_extension(self) -> global___TokenScopeExtension: ...
    def __init__(
        self,
        *,
        jfrog_tenant_id: builtins.str = ...,
        token: builtins.str = ...,
        token_scope_extension: global___TokenScopeExtension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_scope_extension", b"token_scope_extension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_tenant_id", b"jfrog_tenant_id", "token", b"token", "token_scope_extension", b"token_scope_extension"]) -> None: ...

global___PersistTokenClaimsSpec = PersistTokenClaimsSpec

class JFrogTokenRevokeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_TENANT_ID_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    jfrog_tenant_id: builtins.str
    """JFrog tenant id"""
    token: builtins.str
    """Revoke by explicit token"""
    token_id: builtins.str
    """Revoke by token id"""
    def __init__(
        self,
        *,
        jfrog_tenant_id: builtins.str = ...,
        token: builtins.str = ...,
        token_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token", "token_descriptor_type", b"token_descriptor_type", "token_id", b"token_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_tenant_id", b"jfrog_tenant_id", "token", b"token", "token_descriptor_type", b"token_descriptor_type", "token_id", b"token_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["token_descriptor_type", b"token_descriptor_type"]) -> typing_extensions.Literal["token", "token_id"] | None: ...

global___JFrogTokenRevokeSpec = JFrogTokenRevokeSpec

class RepositoryTokenSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Artifactory repository key"""
    type: global___RepositoryType.ValueType
    """Artifactory repository type"""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___JFrogPermissionType.ValueType]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        type: global___RepositoryType.ValueType = ...,
        permissions: collections.abc.Iterable[global___JFrogPermissionType.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "permissions", b"permissions", "type", b"type"]) -> None: ...

global___RepositoryTokenSpec = RepositoryTokenSpec

class JFrogTokenTTLSpec(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////////////////////////////////////////////
    ttl spec
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    REFRESHABLE_FIELD_NUMBER: builtins.int
    @property
    def expiration_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    refreshable: builtins.bool
    """Is token refreshable.
    If true, a refresh token will be added to the response
    """
    def __init__(
        self,
        *,
        expiration_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        refreshable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "optional_expiration_time", b"optional_expiration_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "optional_expiration_time", b"optional_expiration_time", "refreshable", b"refreshable"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_expiration_time", b"optional_expiration_time"]) -> typing_extensions.Literal["expiration_time"] | None: ...

global___JFrogTokenTTLSpec = JFrogTokenTTLSpec

class SubjectAndScopeSource(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////////////////////////////////////////////
    subject & scope
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    SUBJECT_AND_SCOPE_FIELD_NUMBER: builtins.int
    TOKEN_SCOPE_EXTENSION_FIELD_NUMBER: builtins.int
    token: builtins.str
    """Subject and scope will be derived from the claims of the given token"""
    token_id: builtins.str
    """Subject and scope will be derived from the claims of the token represented by the given token_id"""
    @property
    def subject_and_scope(self) -> global___ExplicitSubjectAndScope:
        """Explicit Subject and scope"""
    @property
    def token_scope_extension(self) -> global___TokenScopeExtension:
        """Token with additional scopes"""
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        token_id: builtins.str = ...,
        subject_and_scope: global___ExplicitSubjectAndScope | None = ...,
        token_scope_extension: global___TokenScopeExtension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source", b"source", "subject_and_scope", b"subject_and_scope", "token", b"token", "token_id", b"token_id", "token_scope_extension", b"token_scope_extension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source", b"source", "subject_and_scope", b"subject_and_scope", "token", b"token", "token_id", b"token_id", "token_scope_extension", b"token_scope_extension"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["source", b"source"]) -> typing_extensions.Literal["token", "token_id", "subject_and_scope", "token_scope_extension"] | None: ...

global___SubjectAndScopeSource = SubjectAndScopeSource

class ExplicitSubjectAndScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    subject: builtins.str
    scopes: builtins.str
    """The requested space separated scopes"""
    def __init__(
        self,
        *,
        subject: builtins.str = ...,
        scopes: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["optional_subject", b"optional_subject", "subject", b"subject"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["optional_subject", b"optional_subject", "scopes", b"scopes", "subject", b"subject"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_subject", b"optional_subject"]) -> typing_extensions.Literal["subject"] | None: ...

global___ExplicitSubjectAndScope = ExplicitSubjectAndScope

class JFrogTokenAudiences(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////////////////////////////////////////////
    audience
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCES_FIELD_NUMBER: builtins.int
    @property
    def audiences(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JFrogTokenAudience]:
        """Token audiences"""
    def __init__(
        self,
        *,
        audiences: collections.abc.Iterable[global___JFrogTokenAudience] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audiences", b"audiences"]) -> None: ...

global___JFrogTokenAudiences = JFrogTokenAudiences

class JFrogTokenAudience(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_ML_FIELD_NUMBER: builtins.int
    ARTIFACTORY_FIELD_NUMBER: builtins.int
    XRAY_FIELD_NUMBER: builtins.int
    @property
    def jfrog_ml(self) -> global___JFrogTokenAudienceJFrogML:
        """JFrogML audience"""
    @property
    def artifactory(self) -> global___JFrogTokenAudienceArtifactory:
        """Artifactory audience"""
    @property
    def xray(self) -> global___JFrogTokenAudienceXRay:
        """XRay audience"""
    def __init__(
        self,
        *,
        jfrog_ml: global___JFrogTokenAudienceJFrogML | None = ...,
        artifactory: global___JFrogTokenAudienceArtifactory | None = ...,
        xray: global___JFrogTokenAudienceXRay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifactory", b"artifactory", "jfrog_ml", b"jfrog_ml", "type", b"type", "xray", b"xray"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifactory", b"artifactory", "jfrog_ml", b"jfrog_ml", "type", b"type", "xray", b"xray"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["jfrog_ml", "artifactory", "xray"] | None: ...

global___JFrogTokenAudience = JFrogTokenAudience

class JFrogTokenAudienceArtifactory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___JFrogTokenAudienceArtifactory = JFrogTokenAudienceArtifactory

class JFrogTokenAudienceXRay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___JFrogTokenAudienceXRay = JFrogTokenAudienceXRay

class JFrogTokenAudienceJFrogML(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___JFrogTokenAudienceJFrogML = JFrogTokenAudienceJFrogML

class TokenScopeExtension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    ADDITIONAL_SCOPES_FIELD_NUMBER: builtins.int
    token: builtins.str
    """The given token"""
    @property
    def additional_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of scopes to add to the given token"""
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        additional_scopes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_scopes", b"additional_scopes", "token", b"token"]) -> None: ...

global___TokenScopeExtension = TokenScopeExtension



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/v1/internal/featureset/featureset_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHqwak/feature_store/v1/internal/featureset/featureset_token_service.proto\x12\x34qwak.feature.store.management.v1.internal.featureset\"P\n#GetAuthTokenIdByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\"8\n$GetAuthTokenIdByFeaturesetIdResponse\x12\x10\n\x08token_id\x18\x01 \x01(\t2\xef\x01\n\x15\x46\x65\x61turesetAuthService\x12\xd5\x01\n\x1cGetAuthTokenIdByFeaturesetId\x12Y.qwak.feature.store.management.v1.internal.featureset.GetAuthTokenIdByFeaturesetIdRequest\x1aZ.qwak.feature.store.management.v1.internal.featureset.GetAuthTokenIdByFeaturesetIdResponseBC\n?com.qwak.ai.feature.store.management.v1.api.internal.featuresetP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.v1.internal.featureset.featureset_token_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?com.qwak.ai.feature.store.management.v1.api.internal.featuresetP\001'
  _globals['_GETAUTHTOKENIDBYFEATURESETIDREQUEST']._serialized_start=130
  _globals['_GETAUTHTOKENIDBYFEATURESETIDREQUEST']._serialized_end=210
  _globals['_GETAUTHTOKENIDBYFEATURESETIDRESPONSE']._serialized_start=212
  _globals['_GETAUTHTOKENIDBYFEATURESETIDRESPONSE']._serialized_end=268
  _globals['_FEATURESETAUTHSERVICE']._serialized_start=271
  _globals['_FEATURESETAUTHSERVICE']._serialized_end=510
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/logging/log_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/logging/log_source.proto\x12\x14qwak.logging.service\"\xca\x04\n\tLogSource\x12\x41\n\rmodel_runtime\x18\x01 \x01(\x0b\x32(.qwak.logging.service.ModelRuntimeSourceH\x00\x12?\n\x0cremote_build\x18\x02 \x01(\x0b\x32\'.qwak.logging.service.RemoteBuildSourceH\x00\x12M\n\x13inference_execution\x18\x03 \x01(\x0b\x32..qwak.logging.service.InferenceExecutionSourceH\x00\x12P\n\x15streaming_feature_set\x18\x04 \x01(\x0b\x32/.qwak.logging.service.StreamingFeatureSetSourceH\x00\x12g\n!streaming_aggregation_feature_set\x18\x05 \x01(\x0b\x32:.qwak.logging.service.StreamingAggregationFeatureSetSourceH\x00\x12H\n\x11\x62\x61tch_feature_set\x18\x06 \x01(\x0b\x32+.qwak.logging.service.BatchFeatureSetSourceH\x00\x12[\n\x1breal_time_feature_extractor\x18\x07 \x01(\x0b\x32\x34.qwak.logging.service.RealTimeFeatureExtractorSourceH\x00\x42\x08\n\x06source\"\x92\x01\n\x11RemoteBuildSource\x12\x18\n\x10model_group_name\x18\x03 \x01(\t\x12\x16\n\nmodel_name\x18\x04 \x01(\tB\x02\x18\x01\x12\x12\n\x08model_id\x18\x05 \x01(\tH\x00\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x11\n\tphase_ids\x18\x02 \x03(\tB\x12\n\x10model_identifier\"\xa8\x01\n\x12ModelRuntimeSource\x12\x18\n\x10model_group_name\x18\x03 \x01(\t\x12\x16\n\nmodel_name\x18\x04 \x01(\tB\x02\x18\x01\x12\x12\n\x08model_id\x18\x05 \x01(\tH\x00\x12\x17\n\rdeployment_id\x18\x01 \x01(\tH\x01\x12\x12\n\x08\x62uild_id\x18\x02 \x01(\tH\x01\x42\x12\n\x10model_identifierB\x0b\n\tsearch_by\"\xba\x01\n\x18InferenceExecutionSource\x12\x18\n\x10model_group_name\x18\x03 \x01(\t\x12\x16\n\nmodel_name\x18\x04 \x01(\tB\x02\x18\x01\x12\x12\n\x08model_id\x18\x05 \x01(\tH\x00\x12\x1a\n\x10inference_job_id\x18\x01 \x01(\tH\x01\x12\x1b\n\x11inference_task_id\x18\x02 \x01(\tH\x01\x42\x12\n\x10model_identifierB\x0b\n\tsearch_by\"\xe4\x01\n\x19StreamingFeatureSetSource\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x05 \x01(\t\x12\x34\n\x07offline\x18\x03 \x01(\x0b\x32!.qwak.logging.service.OfflineTypeH\x00\x12\x32\n\x06online\x18\x04 \x01(\x0b\x32 .qwak.logging.service.OnlineTypeH\x00\x42\x06\n\x04type\"\xa4\x01\n\x15\x42\x61tchFeatureSetSource\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x04 \x01(\t\x12&\n\x1a\x66ilter_by_feature_set_name\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x0e\n\x06run_id\x18\x03 \x01(\t\"\xdb\x01\n$StreamingAggregationFeatureSetSource\x12\x37\n\trow_level\x18\x01 \x01(\x0b\x32\".qwak.logging.service.RowLevelTypeH\x00\x12:\n\ncompaction\x18\x02 \x01(\x0b\x32$.qwak.logging.service.CompactionTypeH\x00\x12\x36\n\x08\x62\x61\x63kfill\x18\x03 \x01(\x0b\x32\".qwak.logging.service.BackfillTypeH\x00\x42\x06\n\x04type\"c\n\nOnlineType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x03 \x01(\t\"t\n\x0bOfflineType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\"e\n\x0cRowLevelType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x03 \x01(\t\"w\n\x0e\x43ompactionType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\"e\n\x0c\x42\x61\x63kfillType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x03 \x01(\t\"H\n\x1eRealTimeFeatureExtractorSource\x12&\n\x1ereal_time_feature_extractor_id\x18\x01 \x01(\tB,\n\x1e\x63om.qwak.ai.logging.reader.apiP\x01Z\x08/loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.logging.log_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.logging.reader.apiP\001Z\010/logging'
  _REMOTEBUILDSOURCE.fields_by_name['model_name']._options = None
  _REMOTEBUILDSOURCE.fields_by_name['model_name']._serialized_options = b'\030\001'
  _MODELRUNTIMESOURCE.fields_by_name['model_name']._options = None
  _MODELRUNTIMESOURCE.fields_by_name['model_name']._serialized_options = b'\030\001'
  _INFERENCEEXECUTIONSOURCE.fields_by_name['model_name']._options = None
  _INFERENCEEXECUTIONSOURCE.fields_by_name['model_name']._serialized_options = b'\030\001'
  _BATCHFEATURESETSOURCE.fields_by_name['filter_by_feature_set_name']._options = None
  _BATCHFEATURESETSOURCE.fields_by_name['filter_by_feature_set_name']._serialized_options = b'\030\001'
  _globals['_LOGSOURCE']._serialized_start=56
  _globals['_LOGSOURCE']._serialized_end=642
  _globals['_REMOTEBUILDSOURCE']._serialized_start=645
  _globals['_REMOTEBUILDSOURCE']._serialized_end=791
  _globals['_MODELRUNTIMESOURCE']._serialized_start=794
  _globals['_MODELRUNTIMESOURCE']._serialized_end=962
  _globals['_INFERENCEEXECUTIONSOURCE']._serialized_start=965
  _globals['_INFERENCEEXECUTIONSOURCE']._serialized_end=1151
  _globals['_STREAMINGFEATURESETSOURCE']._serialized_start=1154
  _globals['_STREAMINGFEATURESETSOURCE']._serialized_end=1382
  _globals['_BATCHFEATURESETSOURCE']._serialized_start=1385
  _globals['_BATCHFEATURESETSOURCE']._serialized_end=1549
  _globals['_STREAMINGAGGREGATIONFEATURESETSOURCE']._serialized_start=1552
  _globals['_STREAMINGAGGREGATIONFEATURESETSOURCE']._serialized_end=1771
  _globals['_ONLINETYPE']._serialized_start=1773
  _globals['_ONLINETYPE']._serialized_end=1872
  _globals['_OFFLINETYPE']._serialized_start=1874
  _globals['_OFFLINETYPE']._serialized_end=1990
  _globals['_ROWLEVELTYPE']._serialized_start=1992
  _globals['_ROWLEVELTYPE']._serialized_end=2093
  _globals['_COMPACTIONTYPE']._serialized_start=2095
  _globals['_COMPACTIONTYPE']._serialized_end=2214
  _globals['_BACKFILLTYPE']._serialized_start=2216
  _globals['_BACKFILLTYPE']._serialized_end=2317
  _globals['_REALTIMEFEATUREEXTRACTORSOURCE']._serialized_start=2319
  _globals['_REALTIMEFEATUREEXTRACTORSOURCE']._serialized_end=2391
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MemoryUnitApi:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MemoryUnitApiEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MemoryUnitApi.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_MEMORY_UNIT: _MemoryUnitApi.ValueType  # 0
    MIB: _MemoryUnitApi.ValueType  # 1
    GIB: _MemoryUnitApi.ValueType  # 2

class MemoryUnitApi(_MemoryUnitApi, metaclass=_MemoryUnitApiEnumTypeWrapper): ...

UNKNOWN_MEMORY_UNIT: MemoryUnitApi.ValueType  # 0
MIB: MemoryUnitApi.ValueType  # 1
GIB: MemoryUnitApi.ValueType  # 2
global___MemoryUnitApi = MemoryUnitApi

class _InputFileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InputFileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InputFileType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_INPUT_FILE_TYPE: _InputFileType.ValueType  # 0
    CSV_INPUT_FILE_TYPE: _InputFileType.ValueType  # 1
    FEATHER_INPUT_FILE_TYPE: _InputFileType.ValueType  # 2
    PARQUET_INPUT_FILE_TYPE: _InputFileType.ValueType  # 3

class InputFileType(_InputFileType, metaclass=_InputFileTypeEnumTypeWrapper): ...

UNDEFINED_INPUT_FILE_TYPE: InputFileType.ValueType  # 0
CSV_INPUT_FILE_TYPE: InputFileType.ValueType  # 1
FEATHER_INPUT_FILE_TYPE: InputFileType.ValueType  # 2
PARQUET_INPUT_FILE_TYPE: InputFileType.ValueType  # 3
global___InputFileType = InputFileType

class _OutputFileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OutputFileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OutputFileType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 0
    CSV_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 1
    FEATHER_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 2
    PARQUET_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 3

class OutputFileType(_OutputFileType, metaclass=_OutputFileTypeEnumTypeWrapper): ...

UNDEFINED_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 0
CSV_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 1
FEATHER_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 2
PARQUET_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 3
global___OutputFileType = OutputFileType

class _GpuType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GpuTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GpuType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_GPU: _GpuType.ValueType  # 0
    NVIDIA_K80: _GpuType.ValueType  # 1
    NVIDIA_V100: _GpuType.ValueType  # 2
    NVIDIA_A100: _GpuType.ValueType  # 3
    NVIDIA_T4: _GpuType.ValueType  # 4
    NVIDIA_A10G: _GpuType.ValueType  # 5
    NVIDIA_L4: _GpuType.ValueType  # 6
    NVIDIA_T4_1_4_15: _GpuType.ValueType  # 7
    """More specific node types
    t4.xl
    """
    NVIDIA_T4_1_8_30: _GpuType.ValueType  # 8
    """t4.2xl"""
    NVIDIA_T4_1_16_60: _GpuType.ValueType  # 9
    """t4.4xl"""
    NVIDIA_A100_80GB_8_96_1360: _GpuType.ValueType  # 10
    """a100.8xl"""
    NVIDIA_V100_1_8_52: _GpuType.ValueType  # 11
    """a100.xl"""
    NVIDIA_V100_4_32_208: _GpuType.ValueType  # 12
    """v100.4xl"""

class GpuType(_GpuType, metaclass=_GpuTypeEnumTypeWrapper): ...

INVALID_GPU: GpuType.ValueType  # 0
NVIDIA_K80: GpuType.ValueType  # 1
NVIDIA_V100: GpuType.ValueType  # 2
NVIDIA_A100: GpuType.ValueType  # 3
NVIDIA_T4: GpuType.ValueType  # 4
NVIDIA_A10G: GpuType.ValueType  # 5
NVIDIA_L4: GpuType.ValueType  # 6
NVIDIA_T4_1_4_15: GpuType.ValueType  # 7
"""More specific node types
t4.xl
"""
NVIDIA_T4_1_8_30: GpuType.ValueType  # 8
"""t4.2xl"""
NVIDIA_T4_1_16_60: GpuType.ValueType  # 9
"""t4.4xl"""
NVIDIA_A100_80GB_8_96_1360: GpuType.ValueType  # 10
"""a100.8xl"""
NVIDIA_V100_1_8_52: GpuType.ValueType  # 11
"""a100.xl"""
NVIDIA_V100_4_32_208: GpuType.ValueType  # 12
"""v100.4xl"""
global___GpuType = GpuType

class _CloudProvider:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CloudProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CloudProvider.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_CLOUD_PROVIDER: _CloudProvider.ValueType  # 0
    AWS: _CloudProvider.ValueType  # 1
    GCP: _CloudProvider.ValueType  # 2

class CloudProvider(_CloudProvider, metaclass=_CloudProviderEnumTypeWrapper): ...

UNKNOWN_CLOUD_PROVIDER: CloudProvider.ValueType  # 0
AWS: CloudProvider.ValueType  # 1
GCP: CloudProvider.ValueType  # 2
global___CloudProvider = CloudProvider

class ListInferenceJobFilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    DIRECTORY_PATH_FIELD_NUMBER: builtins.int
    TOKEN_SECRET_FIELD_NUMBER: builtins.int
    SECRET_SECRET_FIELD_NUMBER: builtins.int
    SECRET_SERVICE_URL_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    AWS_CREDENTIALS_FIELD_NUMBER: builtins.int
    GCP_CREDENTIALS_FIELD_NUMBER: builtins.int
    GROUPED_TASK_DETAILS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """The bucket in cloud storage"""
    directory_path: builtins.str
    """The path in the bucket to read the files from"""
    token_secret: builtins.str
    """The qwak secret the bucket's token is stored in"""
    secret_secret: builtins.str
    """The qwak secret the bucket's secret is stored in"""
    secret_service_url: builtins.str
    """The qwak secret service url for that environment"""
    role_arn: builtins.str
    """The role arn to assume"""
    @property
    def aws_credentials(self) -> global___AwsCredentials: ...
    @property
    def gcp_credentials(self) -> global___GcpCredentials: ...
    @property
    def grouped_task_details(self) -> global___GroupedTaskDetails: ...
    environment_id: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        directory_path: builtins.str = ...,
        token_secret: builtins.str = ...,
        secret_secret: builtins.str = ...,
        secret_service_url: builtins.str = ...,
        role_arn: builtins.str = ...,
        aws_credentials: global___AwsCredentials | None = ...,
        gcp_credentials: global___GcpCredentials | None = ...,
        grouped_task_details: global___GroupedTaskDetails | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_credentials", b"aws_credentials", "cloud_client_credentials", b"cloud_client_credentials", "gcp_credentials", b"gcp_credentials", "grouped_task_details", b"grouped_task_details", "task_flow", b"task_flow"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_credentials", b"aws_credentials", "bucket", b"bucket", "cloud_client_credentials", b"cloud_client_credentials", "directory_path", b"directory_path", "environment_id", b"environment_id", "gcp_credentials", b"gcp_credentials", "grouped_task_details", b"grouped_task_details", "role_arn", b"role_arn", "secret_secret", b"secret_secret", "secret_service_url", b"secret_service_url", "task_flow", b"task_flow", "token_secret", b"token_secret"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cloud_client_credentials", b"cloud_client_credentials"]) -> typing_extensions.Literal["aws_credentials", "gcp_credentials"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["task_flow", b"task_flow"]) -> typing_extensions.Literal["grouped_task_details"] | None: ...

global___ListInferenceJobFilesRequest = ListInferenceJobFilesRequest

class GroupedTaskDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONCURRENTTASKS_FIELD_NUMBER: builtins.int
    DESTINATION_PATH_FIELD_NUMBER: builtins.int
    DESTINATION_BUCKET_FIELD_NUMBER: builtins.int
    concurrentTasks: builtins.int
    """concurrent task to divide files to group"""
    destination_path: builtins.str
    """path to upload temp point files"""
    destination_bucket: builtins.str
    """The destination bucket in cloud storage"""
    def __init__(
        self,
        *,
        concurrentTasks: builtins.int = ...,
        destination_path: builtins.str = ...,
        destination_bucket: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["concurrentTasks", b"concurrentTasks", "destination_bucket", b"destination_bucket", "destination_path", b"destination_path"]) -> None: ...

global___GroupedTaskDetails = GroupedTaskDetails

class CleanStorageObjectFromCloudStorageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    OBJECT_PREFIX_FIELD_NUMBER: builtins.int
    SECRET_SERVICE_URL_FIELD_NUMBER: builtins.int
    AWS_CREDENTIALS_FIELD_NUMBER: builtins.int
    GCP_CREDENTIALS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """The bucket in cloud storage"""
    @property
    def object_prefix(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The path in the objects to delete"""
    secret_service_url: builtins.str
    """The qwak secret service url for that environment"""
    @property
    def aws_credentials(self) -> global___AwsCredentials: ...
    @property
    def gcp_credentials(self) -> global___GcpCredentials: ...
    environment_id: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        object_prefix: collections.abc.Iterable[builtins.str] | None = ...,
        secret_service_url: builtins.str = ...,
        aws_credentials: global___AwsCredentials | None = ...,
        gcp_credentials: global___GcpCredentials | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_credentials", b"aws_credentials", "cloud_client_credentials", b"cloud_client_credentials", "gcp_credentials", b"gcp_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_credentials", b"aws_credentials", "bucket", b"bucket", "cloud_client_credentials", b"cloud_client_credentials", "environment_id", b"environment_id", "gcp_credentials", b"gcp_credentials", "object_prefix", b"object_prefix", "secret_service_url", b"secret_service_url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cloud_client_credentials", b"cloud_client_credentials"]) -> typing_extensions.Literal["aws_credentials", "gcp_credentials"] | None: ...

global___CleanStorageObjectFromCloudStorageRequest = CleanStorageObjectFromCloudStorageRequest

class AwsCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_ARN_FIELD_NUMBER: builtins.int
    TOKEN_SECRET_FIELD_NUMBER: builtins.int
    SECRET_SECRET_FIELD_NUMBER: builtins.int
    role_arn: builtins.str
    """The role arn to assume"""
    token_secret: builtins.str
    """The qwak secret the bucket's token is stored in"""
    secret_secret: builtins.str
    """The qwak secret the bucket's secret is stored in"""
    def __init__(
        self,
        *,
        role_arn: builtins.str = ...,
        token_secret: builtins.str = ...,
        secret_secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["role_arn", b"role_arn", "secret_secret", b"secret_secret", "token_secret", b"token_secret"]) -> None: ...

global___AwsCredentials = AwsCredentials

class GcpCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_JSON_KEY_SECRET_FIELD_NUMBER: builtins.int
    service_account_json_key_secret: builtins.str
    def __init__(
        self,
        *,
        service_account_json_key_secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_account_json_key_secret", b"service_account_json_key_secret"]) -> None: ...

global___GcpCredentials = GcpCredentials

class ListInferenceJobFilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_NAMES_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    LIST_FILE_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def file_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The list of files in the folder"""
    success: builtins.bool
    """Whether the request was successful or not"""
    failure_reason: builtins.str
    """The failure description"""
    @property
    def list_file_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListFileDetails]:
        """the list of file details"""
    def __init__(
        self,
        *,
        file_names: collections.abc.Iterable[builtins.str] | None = ...,
        success: builtins.bool = ...,
        failure_reason: builtins.str = ...,
        list_file_details: collections.abc.Iterable[global___ListFileDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_reason", b"failure_reason", "file_names", b"file_names", "list_file_details", b"list_file_details", "success", b"success"]) -> None: ...

global___ListInferenceJobFilesResponse = ListInferenceJobFilesResponse

class ListFileDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_POINT_FILE_FIELD_NUMBER: builtins.int
    POINT_FILE_PATH_FIELD_NUMBER: builtins.int
    OBJECT_PATHS_FIELD_NUMBER: builtins.int
    is_point_file: builtins.bool
    """Is point file is used - for admiral flow (intermediate state till we removed kube flow - MLOPS-2201)"""
    point_file_path: builtins.str
    """point file path"""
    @property
    def object_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of inference files"""
    def __init__(
        self,
        *,
        is_point_file: builtins.bool = ...,
        point_file_path: builtins.str = ...,
        object_paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_point_file", b"is_point_file", "object_paths", b"object_paths", "point_file_path", b"point_file_path"]) -> None: ...

global___ListFileDetails = ListFileDetails

class CreateInferenceTaskExecutorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_EXECUTOR_CONFIGURATION_FIELD_NUMBER: builtins.int
    INFERENCE_TASK_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def task_executor_configuration(self) -> global___TaskExecutorConfigurationMessage: ...
    @property
    def inference_task_configuration(self) -> global___InferenceTaskConfigurationMessage: ...
    def __init__(
        self,
        *,
        task_executor_configuration: global___TaskExecutorConfigurationMessage | None = ...,
        inference_task_configuration: global___InferenceTaskConfigurationMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inference_task_configuration", b"inference_task_configuration", "task_executor_configuration", b"task_executor_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inference_task_configuration", b"inference_task_configuration", "task_executor_configuration", b"task_executor_configuration"]) -> None: ...

global___CreateInferenceTaskExecutorRequest = CreateInferenceTaskExecutorRequest

class PrepareInferenceJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFERENCE_JOB_CONFIGURATION_MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def inference_job_configuration_message(self) -> global___InferenceJobConfigurationMessage: ...
    def __init__(
        self,
        *,
        inference_job_configuration_message: global___InferenceJobConfigurationMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inference_job_configuration_message", b"inference_job_configuration_message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inference_job_configuration_message", b"inference_job_configuration_message"]) -> None: ...

global___PrepareInferenceJobRequest = PrepareInferenceJobRequest

class PrepareInferenceJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the request was successful or not"""
    failure_reason: builtins.str
    """The failure description"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_reason", b"failure_reason", "success", b"success"]) -> None: ...

global___PrepareInferenceJobResponse = PrepareInferenceJobResponse

class TaskExecutorConfigurationMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFERENCE_JOB_ID_FIELD_NUMBER: builtins.int
    INFERENCE_TASK_ID_FIELD_NUMBER: builtins.int
    MODEL_IDENTIFIER_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    BACKOFF_LIMIT_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CUSTOM_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    JOB_SIZE_FIELD_NUMBER: builtins.int
    PURCHASE_OPTION_FIELD_NUMBER: builtins.int
    IMAGE_PULL_SECRET_FIELD_NUMBER: builtins.int
    CUSTOM_SERVICE_ACCOUNT_SECRET_FIELD_NUMBER: builtins.int
    JFROG_TOKEN_API_SECRET_NAME_FIELD_NUMBER: builtins.int
    JFROG_BASE_URL_FIELD_NUMBER: builtins.int
    inference_job_id: builtins.str
    """The id of the inference job"""
    inference_task_id: builtins.str
    """The id of the current inference task"""
    @property
    def model_identifier(self) -> global___ModelIdentifier:
        """Model details"""
    image_url: builtins.str
    """The image url to use"""
    backoff_limit: builtins.int
    """How many times the current task can fail"""
    cpu: builtins.float
    """Cpu usage"""
    memory_amount: builtins.int
    """Memory usage"""
    memory_units: global___MemoryUnitApi.ValueType
    """Units type of memory"""
    environment_id: builtins.str
    custom_iam_role_arn: builtins.str
    @property
    def job_size(self) -> global___BatchJobResources: ...
    purchase_option: builtins.str
    """Whether it is spot/ondemand (default - spot)"""
    image_pull_secret: builtins.str
    """If the image saved in out source repository (jfrog e.g.)  and image pull secret is needed"""
    custom_service_account_secret: builtins.str
    """The custom service account json key secret for gcp"""
    jfrog_token_api_secret_name: builtins.str
    """The Token secret name for jfrog token"""
    jfrog_base_url: builtins.str
    """The Jfrog base url"""
    def __init__(
        self,
        *,
        inference_job_id: builtins.str = ...,
        inference_task_id: builtins.str = ...,
        model_identifier: global___ModelIdentifier | None = ...,
        image_url: builtins.str = ...,
        backoff_limit: builtins.int = ...,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___MemoryUnitApi.ValueType = ...,
        environment_id: builtins.str = ...,
        custom_iam_role_arn: builtins.str = ...,
        job_size: global___BatchJobResources | None = ...,
        purchase_option: builtins.str = ...,
        image_pull_secret: builtins.str = ...,
        custom_service_account_secret: builtins.str = ...,
        jfrog_token_api_secret_name: builtins.str = ...,
        jfrog_base_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_size", b"job_size", "model_identifier", b"model_identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backoff_limit", b"backoff_limit", "cpu", b"cpu", "custom_iam_role_arn", b"custom_iam_role_arn", "custom_service_account_secret", b"custom_service_account_secret", "environment_id", b"environment_id", "image_pull_secret", b"image_pull_secret", "image_url", b"image_url", "inference_job_id", b"inference_job_id", "inference_task_id", b"inference_task_id", "jfrog_base_url", b"jfrog_base_url", "jfrog_token_api_secret_name", b"jfrog_token_api_secret_name", "job_size", b"job_size", "memory_amount", b"memory_amount", "memory_units", b"memory_units", "model_identifier", b"model_identifier", "purchase_option", b"purchase_option"]) -> None: ...

global___TaskExecutorConfigurationMessage = TaskExecutorConfigurationMessage

class InferenceJobConfigurationMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFERENCE_JOB_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CUSTOM_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    inference_job_id: builtins.str
    """The id of the inference job"""
    environment_id: builtins.str
    """Environment id"""
    custom_iam_role_arn: builtins.str
    """Custom IAm role"""
    def __init__(
        self,
        *,
        inference_job_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        custom_iam_role_arn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_iam_role_arn", b"custom_iam_role_arn", "environment_id", b"environment_id", "inference_job_id", b"inference_job_id"]) -> None: ...

global___InferenceJobConfigurationMessage = InferenceJobConfigurationMessage

class ModelIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    build_id: builtins.str
    branch_id: builtins.str
    model_uuid: builtins.str
    model_group_name: builtins.str
    """the model group this model belongs to. Currently model group name is identical to the project name for jfrog flows.
    in case this changes, the project name should not be assigned to the model group name anymore.
    """
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        model_uuid: builtins.str = ...,
        model_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "model_group_name", b"model_group_name", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> None: ...

global___ModelIdentifier = ModelIdentifier

class ListFilesPreStepConfiguration(google.protobuf.message.Message):
    """will be deprecated soon"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_PATH_FIELD_NUMBER: builtins.int
    LIST_FILES_FILE_NAME_FIELD_NUMBER: builtins.int
    TOTAL_NUMBER_OF_TASKS_FIELD_NUMBER: builtins.int
    TASK_INDEX_FIELD_NUMBER: builtins.int
    source_path: builtins.str
    """Directory path in source bucket of data files to run inference on"""
    list_files_file_name: builtins.str
    """Name for the file to save the list of files in the source path"""
    total_number_of_tasks: builtins.int
    """Total number of inference tasks, used to divide the files list into similarly sized groups"""
    @property
    def task_index(self) -> google.protobuf.wrappers_pb2.Int32Value:
        """Index of the specific task, used to determine on which files group to run inference on. value 0 is legit"""
    def __init__(
        self,
        *,
        source_path: builtins.str = ...,
        list_files_file_name: builtins.str = ...,
        total_number_of_tasks: builtins.int = ...,
        task_index: google.protobuf.wrappers_pb2.Int32Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["task_index", b"task_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["list_files_file_name", b"list_files_file_name", "source_path", b"source_path", "task_index", b"task_index", "total_number_of_tasks", b"total_number_of_tasks"]) -> None: ...

global___ListFilesPreStepConfiguration = ListFilesPreStepConfiguration

class InferenceTaskConfigurationMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_BUCKET_FIELD_NUMBER: builtins.int
    DESTINATION_BUCKET_FIELD_NUMBER: builtins.int
    FILEPATH_FIELD_NUMBER: builtins.int
    DESTINATION_PATH_FIELD_NUMBER: builtins.int
    INPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    OUTPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    TOKEN_SECRET_FIELD_NUMBER: builtins.int
    SECRET_SECRET_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_JSON_KEY_SECRET_FIELD_NUMBER: builtins.int
    IS_POINT_FILE_PATH_FIELD_NUMBER: builtins.int
    LIST_FILES_PRE_STEP_CONFIGURATION_FIELD_NUMBER: builtins.int
    SESSION_TOKEN_FIELD_NUMBER: builtins.int
    source_bucket: builtins.str
    """The source bucket in cloud storage"""
    destination_bucket: builtins.str
    """The destination bucket in cloud storage"""
    filepath: builtins.str
    """The full file path to process"""
    destination_path: builtins.str
    """The destination path to save results to"""
    input_file_type: global___InputFileType.ValueType
    """The input file type"""
    output_file_type: global___OutputFileType.ValueType
    """The output file type"""
    token_secret: builtins.str
    """The qwak secret the bucket's token is stored in"""
    secret_secret: builtins.str
    """The qwak secret the bucket's secret is stored in"""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchJobParameter]:
        """User provided parameters which will be passed to the batch execution job as environment variables"""
    cloud_provider: global___CloudProvider.ValueType
    """The cloud provider"""
    service_account_json_key_secret: builtins.str
    """The service account json key secret"""
    is_point_file_path: builtins.bool
    """Is the file contains points to inference files"""
    @property
    def list_files_pre_step_configuration(self) -> global___ListFilesPreStepConfiguration:
        """Optional pre step configuration, used to list files in the source directory and run inference on subset of files"""
    session_token: builtins.str
    """the session token required to use the bucket for batch inference"""
    def __init__(
        self,
        *,
        source_bucket: builtins.str = ...,
        destination_bucket: builtins.str = ...,
        filepath: builtins.str = ...,
        destination_path: builtins.str = ...,
        input_file_type: global___InputFileType.ValueType = ...,
        output_file_type: global___OutputFileType.ValueType = ...,
        token_secret: builtins.str = ...,
        secret_secret: builtins.str = ...,
        parameters: collections.abc.Iterable[global___BatchJobParameter] | None = ...,
        cloud_provider: global___CloudProvider.ValueType = ...,
        service_account_json_key_secret: builtins.str = ...,
        is_point_file_path: builtins.bool = ...,
        list_files_pre_step_configuration: global___ListFilesPreStepConfiguration | None = ...,
        session_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["list_files_pre_step_configuration", b"list_files_pre_step_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_provider", b"cloud_provider", "destination_bucket", b"destination_bucket", "destination_path", b"destination_path", "filepath", b"filepath", "input_file_type", b"input_file_type", "is_point_file_path", b"is_point_file_path", "list_files_pre_step_configuration", b"list_files_pre_step_configuration", "output_file_type", b"output_file_type", "parameters", b"parameters", "secret_secret", b"secret_secret", "service_account_json_key_secret", b"service_account_json_key_secret", "session_token", b"session_token", "source_bucket", b"source_bucket", "token_secret", b"token_secret"]) -> None: ...

global___InferenceTaskConfigurationMessage = InferenceTaskConfigurationMessage

class BatchJobParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___BatchJobParameter = BatchJobParameter

class CleanInferenceTasksExecutorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFERENCE_JOB_ID_FIELD_NUMBER: builtins.int
    inference_job_id: builtins.str
    """The id of the inference job"""
    def __init__(
        self,
        *,
        inference_job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inference_job_id", b"inference_job_id"]) -> None: ...

global___CleanInferenceTasksExecutorsRequest = CleanInferenceTasksExecutorsRequest

class CleanInferenceTasksExecutorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the request was successful or not"""
    failure_reason: builtins.str
    """The failure description"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_reason", b"failure_reason", "success", b"success"]) -> None: ...

global___CleanInferenceTasksExecutorsResponse = CleanInferenceTasksExecutorsResponse

class CleanInferenceTaskExecutorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFERENCE_JOB_ID_FIELD_NUMBER: builtins.int
    INFERENCE_TASK_ID_FIELD_NUMBER: builtins.int
    inference_job_id: builtins.str
    """The id of the inference job"""
    inference_task_id: builtins.str
    """The id of the inference task"""
    def __init__(
        self,
        *,
        inference_job_id: builtins.str = ...,
        inference_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inference_job_id", b"inference_job_id", "inference_task_id", b"inference_task_id"]) -> None: ...

global___CleanInferenceTaskExecutorRequest = CleanInferenceTaskExecutorRequest

class CleanInferenceTaskExecutorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the request was successful or not"""
    failure_reason: builtins.str
    """The failure description"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_reason", b"failure_reason", "success", b"success"]) -> None: ...

global___CleanInferenceTaskExecutorResponse = CleanInferenceTaskExecutorResponse

class CreateInferenceTaskExecutorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the request was successful or not"""
    failure_reason: builtins.str
    """The failure description"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_reason", b"failure_reason", "success", b"success"]) -> None: ...

global___CreateInferenceTaskExecutorResponse = CreateInferenceTaskExecutorResponse

class StartInferenceJobWarmupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    EXECUTORS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    JOB_SIZE_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    IMAGE_PULL_SECRET_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model details"""
    branch_id: builtins.str
    """branch id"""
    build_id: builtins.str
    """Build Id"""
    image_url: builtins.str
    """The image url to use"""
    cpu: builtins.float
    """Cpu usage"""
    memory_amount: builtins.int
    """Memory usage"""
    memory_units: global___MemoryUnitApi.ValueType
    """Units type of memory"""
    executors: builtins.int
    """Number of executors"""
    timeout: builtins.int
    """Warmup timeout in seconds"""
    @property
    def job_size(self) -> global___BatchJobResources: ...
    model_uuid: builtins.str
    image_pull_secret: builtins.str
    """Image pull secret"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        image_url: builtins.str = ...,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___MemoryUnitApi.ValueType = ...,
        executors: builtins.int = ...,
        timeout: builtins.int = ...,
        job_size: global___BatchJobResources | None = ...,
        model_uuid: builtins.str = ...,
        image_pull_secret: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_size", b"job_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "cpu", b"cpu", "executors", b"executors", "image_pull_secret", b"image_pull_secret", "image_url", b"image_url", "job_size", b"job_size", "memory_amount", b"memory_amount", "memory_units", b"memory_units", "model_id", b"model_id", "model_uuid", b"model_uuid", "timeout", b"timeout"]) -> None: ...

global___StartInferenceJobWarmupRequest = StartInferenceJobWarmupRequest

class StartInferenceJobWarmupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartInferenceJobWarmupResponse = StartInferenceJobWarmupResponse

class CancelInferenceJobWarmupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    branch_id: builtins.str
    build_id: builtins.str
    model_uuid: builtins.str
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> None: ...

global___CancelInferenceJobWarmupRequest = CancelInferenceJobWarmupRequest

class CancelInferenceJobWarmupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelInferenceJobWarmupResponse = CancelInferenceJobWarmupResponse

class BatchJobResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMBER_OF_PODS_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    GPU_RESOURCES_FIELD_NUMBER: builtins.int
    number_of_pods: builtins.int
    """Number of pods to deploy"""
    cpu: builtins.float
    """Cpu"""
    memory_amount: builtins.int
    """Amount of memory"""
    memory_units: global___MemoryUnitApi.ValueType
    """Units type of memory"""
    @property
    def gpu_resources(self) -> global___GpuResources:
        """Optional GPU resources for batch"""
    def __init__(
        self,
        *,
        number_of_pods: builtins.int = ...,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___MemoryUnitApi.ValueType = ...,
        gpu_resources: global___GpuResources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gpu_resources", b"gpu_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "gpu_resources", b"gpu_resources", "memory_amount", b"memory_amount", "memory_units", b"memory_units", "number_of_pods", b"number_of_pods"]) -> None: ...

global___BatchJobResources = BatchJobResources

class GpuResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_TYPE_FIELD_NUMBER: builtins.int
    GPU_AMOUNT_FIELD_NUMBER: builtins.int
    gpu_type: global___GpuType.ValueType
    """The type of the GPU"""
    gpu_amount: builtins.int
    """Amount of GPUs"""
    def __init__(
        self,
        *,
        gpu_type: global___GpuType.ValueType = ...,
        gpu_amount: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gpu_amount", b"gpu_amount", "gpu_type", b"gpu_type"]) -> None: ...

global___GpuResources = GpuResources



from typing import cast

from _qwak_proto.qwak.feature_store.sinks.sink_pb2 import (
    KafkaSink as ProtoKafkaSink,
    StreamingAttachmentPoint as ProtoStreamingAttachmentPoint,
    StreamingSink as ProtoStreamingSink,
)
from qwak.feature_store.data_sources.streaming.kafka.authentication import (
    BaseAuthentication,
)
from qwak.feature_store.sinks.base import BaseSink
from qwak.feature_store.sinks.kafka import (
    KafkaSink,
    MessageFormat as KafkaMessageFormat,
)
from qwak.feature_store.sinks.streaming.attachment import (
    OfflineStreamingAttachmentPoint,
    OnlineStreamingAttachmentPoint,
    StreamingAttachmentPoint,
)


class StreamingSinkFactory:
    @staticmethod
    def get_streaming_sink(proto_streaming_sink: ProtoStreamingSink) -> BaseSink:
        sink_type = proto_streaming_sink.WhichOneof("sink_type")

        auth_conf: BaseAuthentication  # noqa: F842
        if sink_type == "kafka_sink":
            proto_kafka_sink: ProtoKafkaSink = proto_streaming_sink.kafka_sink
            auth_configuration: BaseAuthentication = cast(
                BaseAuthentication,
                BaseAuthentication._from_proto(proto_kafka_sink.auth_config),
            )
            return KafkaSink(
                name=proto_streaming_sink.name,
                topic=proto_kafka_sink.topic,
                bootstrap_servers=proto_kafka_sink.bootstrap_servers,
                message_format=KafkaMessageFormat(proto_kafka_sink.message_format),
                auth_configuration=auth_configuration,
                attachment_point=StreamingSinkFactory._get_attachment_point(
                    proto_streaming_sink.attachment_point
                ),
            )

    @staticmethod
    def _get_attachment_point(
        proto_attachment_point: ProtoStreamingAttachmentPoint,
    ) -> StreamingAttachmentPoint:
        attachment_point_type = proto_attachment_point.WhichOneof(
            "attachment_point_type"
        )
        if attachment_point_type == "online_streaming_attachment_point":
            return OnlineStreamingAttachmentPoint()
        elif attachment_point_type == "offline_streaming_attachment_point":
            return OfflineStreamingAttachmentPoint()
        else:
            raise ValueError(
                f"Unidentified streaming attachment point type: {attachment_point_type}"
            )
